.. These are examples of badges you might want to add to your README:
   please update the URLs accordingly

    .. image:: https://api.cirrus-ci.com/github/<USER>/foundationlive.svg?branch=main
        :alt: Built Status
        :target: https://cirrus-ci.com/github/<USER>/foundationlive
    .. image:: https://readthedocs.org/projects/foundationlive/badge/?version=latest
        :alt: ReadTheDocs
        :target: https://foundationlive.readthedocs.io/en/stable/
    .. image:: https://img.shields.io/coveralls/github/<USER>/foundationlive/main.svg
        :alt: Coveralls
        :target: https://coveralls.io/r/<USER>/foundationlive
    .. image:: https://img.shields.io/pypi/v/foundationlive.svg
        :alt: PyPI-Server
        :target: https://pypi.org/project/foundationlive/
    .. image:: https://img.shields.io/conda/vn/conda-forge/foundationlive.svg
        :alt: Conda-Forge
        :target: https://anaconda.org/conda-forge/foundationlive
    .. image:: https://pepy.tech/badge/foundationlive/month
        :alt: Monthly Downloads
        :target: https://pepy.tech/project/foundationlive
    .. image:: https://img.shields.io/twitter/url/http/shields.io.svg?style=social&label=Twitter
        :alt: Twitter
        :target: https://twitter.com/foundationlive

.. image:: https://img.shields.io/badge/-PyScaffold-005CA0?logo=pyscaffold
    :alt: Project generated with PyScaffold
    :target: https://pyscaffold.org/

|

==============
foundationlive
==============


    Add a short description here!


A longer description of your project goes here...


.. _pyscaffold-notes:

Making Changes & Contributing
=============================

This project uses `pre-commit`_, please make sure to install it before making any
changes::

    pip install pre-commit
    cd foundationlive
    pre-commit install

It is a good idea to update the hooks to the latest version::

    pre-commit autoupdate

Don't forget to tell your contributors to also install and use pre-commit.

.. _pre-commit: https://pre-commit.com/

Note
====

This project has been set up using PyScaffold 4.3.1. For details and usage
information on PyScaffold see https://pyscaffold.org/.
